mclf: Computing with Models of Curves over Local Fields
=======================================================

Description
-----------

Sage toolbox for computing with Models of Curves over Local Fields

License
-------

GPLv2

Upstream Contact
----------------

- https://pypi.org/project/mclf/
- https://github.com/passagemath/passagemath-pkg-mclf
